package com.example.hellsbells;

import java.util.List;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import com.example.hellsbells.beans.Producto;



public class MiAdaptadorPedidoAlmacen extends BaseAdapter {

    private final Activity actividad;
    private final List<Producto> lista;



    public MiAdaptadorPedidoAlmacen(Activity actividad, List<Producto> lista) {
          super();
          this.actividad = actividad;
          this.lista = lista;

    }

    public View getView(int position, View convertView, final ViewGroup parent) {

          LayoutInflater inflater = actividad.getLayoutInflater();

          View view = inflater.inflate(R.layout.elemento_lista_almacen, null, true); 

          TextView textView =(TextView)view.findViewById(R.id.textPedidoAlmacen);
          textView.setText("- "+lista.get(position).getNombre());
          
          
          String precio = String.format("%.2f", lista.get(position).getPrecio())+" ";
          TextView textViewCantidad =(TextView)view.findViewById(R.id.textPedidoAlmacenCantidad);
          textViewCantidad.setText(precio+" - cantidad "+lista.get(position).getCantidadStock());
          
          final Producto dataModel = lista.get(position);
          
          view.setOnLongClickListener(new View.OnLongClickListener() {
	            @Override
				public boolean onLongClick(View v) {
	            	actualizarProducto(v, parent.getContext(), dataModel);
					return false;
				}
          });
         
          return view;

    }
    
    public void actualizarProducto(View view, final Context ctx, final Producto producto){
    	LayoutInflater li = LayoutInflater.from(ctx);
		View promptsView = li.inflate(R.layout.actualizar_producto, null);

		final EditText nombre = (EditText) promptsView.findViewById(R.id.editTextNombre);
		final EditText cantidad = (EditText) promptsView.findViewById(R.id.editTextCantidad);
		final EditText precio = (EditText) promptsView.findViewById(R.id.editTextPrecio);
		
		nombre.setText(producto.getNombre());
		cantidad.setText(producto.getCantidadStock()+"");
		precio.setText(producto.getPrecio()+"");
		
		AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(ctx);
		alertDialogBuilder.setView(promptsView);

		alertDialogBuilder.setPositiveButton("Guardar", new DialogInterface.OnClickListener() {

	      public void onClick(DialogInterface dialog, int id) {
	    	  	    	  
	    	  if(nombre.getText().toString().equals("") || cantidad.getText().toString().equals("")
	    			  || precio.getText().toString().equals("")){
		    		Toast.makeText(ctx, "Todos los datos son obligatorios", Toast.LENGTH_LONG).show();
		    	}else{
	    	  
		    	  MainActivity.basedatos.updateProducto(nombre.getText().toString(), cantidad.getText().toString(),
		    			  precio.getText().toString().trim().replace(",", "."), producto.getId());
			    	Toast.makeText(ctx, "Producto actualizado", Toast.LENGTH_SHORT).show();
			    	((Activity)ctx).finish();
			    	
	      		}

	    }}); 

		alertDialogBuilder.setNegativeButton("Eliminar", new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog,int id) {
		    	MainActivity.basedatos.deleteProducto(producto.getId());
		    	Toast.makeText(ctx, "Producto eliminado", Toast.LENGTH_SHORT).show();
		    	((Activity)ctx).finish();
		    }
	    }); 

		alertDialogBuilder.setNeutralButton("Cancelar", new DialogInterface.OnClickListener() {
	      public void onClick(DialogInterface dialog, int id) {
	    	  ((Activity)ctx).finish();
	    }});
		
		

		AlertDialog alertDialog = alertDialogBuilder.create();
		alertDialog.show();
	}
    
    
    public int getCount() {
          return lista.size();
    }

    public Object getItem(int arg0) {
          return lista.get(arg0);
    }


    public long getItemId(int position) {
          return position;
    }

}